# NOTE:
# It would be greate to create an error reference available in the docs
# So every CLI error will link the correspoinding error in the docs


class Error(Exception):
    """Livemark error"""

    pass
